.. isotree documentation master file, created by
   sphinx-quickstart on Wed Oct 23 21:57:56 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Isolation-based Outlier Detection
=================================
See project webpage for more details:

`<https://www.github.com/david-cortes/isotree>`_

For an example notebook showcasing the package usage, see this link:

`<https://nbviewer.jupyter.org/github/david-cortes/isotree/blob/master/example/isotree_example.ipynb>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: isotree
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
